@@ -130,7 +130,7 @@ public:
     TNode<T> *get() const { return FCurrent; }
 
     TNodeIterator<T>& operator++() { increment(); return *this; }
-    TNodeIterator<T>& operator--() { declrement(); return *this; }
+    TNodeIterator<T>& operator--() { decrement(); return *this; }
 };
 
 template<typename T>
